@@ -1,19 +1,18 @@
 from pathlib import Path
 from typing import Dict, Union
 
-from .constants import Props
-from ._canberra import Context
+from . import Context, Props
 
 
 def play(props: Dict[Union[str, Props], str] = None, **other_props: str) -> Context:
     """Play a sound with the specified props
 
     :param props:
-        A mapping of Props to string values to pass to libcanberra
+        A mapping of :class:`Props` to values.
 
     :param other_props:
-        The Props.XYZ members may be passed as XYZ='val' or xyz='val'
-        (i.e. uppercase or lowercase) in the kwargs.
+        :class:`Props` may also be passed as kwargs, where ``{Props.EVENT_ID: 'bell'}``
+        is passed as ``event_id='bell'``.
 
     :return:
         The canberra.Context used to play the sound. `cancel()` may be called
@@ -32,12 +31,12 @@ def play_file(filename: Union[str, Path], **other_props: str) -> Context:
         Path to the sound file to be played
 
     :param other_props:
-        Additional props (e.g. Props.XYZ), passed as XYZ='val' or xyz='val'
-        in the kwargs.
+        :class:`Props` passed as kwargs, where ``{Props.EVENT_ID: 'bell'}`` is
+        passed as ``event_id='bell'``.
 
     :return:
-        The canberra.Context used to play the sound. `cancel()` may be called
-        on this context to stop the playing sound.
+        The :class:`canberra.Context` used to play the sound. `cancel()` may be
+        called on this context to stop the playing sound.
 
     """
     filename = str(filename)
